lcvtoolbox.vision.geometry.primitives.points\_map.Points3DMap
=============================================================

.. currentmodule:: lcvtoolbox.vision.geometry.primitives.points_map

.. autoclass:: Points3DMap
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:
   :special-members: __init__, __str__, __repr__

   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~Points3DMap.__init__
      ~Points3DMap.apply_mask
      ~Points3DMap.clamp
      ~Points3DMap.compute_normals
      ~Points3DMap.copy
      ~Points3DMap.downsample
      ~Points3DMap.extract_region
      ~Points3DMap.from_depth_map
      ~Points3DMap.from_normal_map
      ~Points3DMap.from_uv_map
      ~Points3DMap.load
      ~Points3DMap.normalize
      ~Points3DMap.ones
      ~Points3DMap.rotate_3d
      ~Points3DMap.sample_points
      ~Points3DMap.save
      ~Points3DMap.scale
      ~Points3DMap.smooth
      ~Points3DMap.to_depth_map
      ~Points3DMap.to_numpy
      ~Points3DMap.to_points_array
      ~Points3DMap.translate
      ~Points3DMap.upsample
      ~Points3DMap.zeros
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Points3DMap.bounds
      ~Points3DMap.centroid
      ~Points3DMap.data
      ~Points3DMap.height
      ~Points3DMap.magnitude_map
      ~Points3DMap.mean
      ~Points3DMap.shape
      ~Points3DMap.size
      ~Points3DMap.width
      ~Points3DMap.x
      ~Points3DMap.y
      ~Points3DMap.z
   
   